@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/iam/IAM_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/iam/IAM_EXPORTS.h>
 
-namespace Aws
-{
-namespace IAM
-{
-namespace Model
-{
-  enum class StatusType
-  {
-    NOT_SET,
-    Active,
-    Inactive,
-    Expired
-  };
+namespace Aws {
+namespace IAM {
+namespace Model {
+enum class StatusType { NOT_SET, Active, Inactive, Expired };
 
-namespace StatusTypeMapper
-{
+namespace StatusTypeMapper {
 AWS_IAM_API StatusType GetStatusTypeForName(const Aws::String& name);
 
 AWS_IAM_API Aws::String GetNameForStatusType(StatusType value);
-} // namespace StatusTypeMapper
-} // namespace Model
-} // namespace IAM
-} // namespace Aws
+}  // namespace StatusTypeMapper
+}  // namespace Model
+}  // namespace IAM
+}  // namespace Aws
